<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:fo="http://www.w3.org/1999/XSL/Format" 
xmlns:office="http://openoffice.org/2000/office" 
xmlns:style="http://openoffice.org/2000/style" 
xmlns:text="http://openoffice.org/2000/text" 
xmlns:table="http://openoffice.org/2000/table" 
xmlns:draw="http://openoffice.org/2000/drawing"  
xmlns:xlink="http://www.w3.org/1999/xlink" 
xmlns:dc="http://purl.org/dc/elements/1.1/" 
xmlns:meta="http://openoffice.org/2000/meta" 
xmlns:number="http://openoffice.org/2000/datastyle" 
xmlns:svg="http://www.w3.org/2000/svg" 
xmlns:chart="http://openoffice.org/2000/chart" 
xmlns:dr3d="http://openoffice.org/2000/dr3d" 
xmlns:math="http://www.w3.org/1998/Math/MathML" 
xmlns:form="http://openoffice.org/2000/form" 
xmlns:script="http://openoffice.org/2000/script" 
xmlns:config="http://openoffice.org/2001/config" 
xmlns:help="http://openoffice.org/2000/help" 
xmlns:ooo="urn:ooohelp"
office:class="text" office:version="1.0"
exclude-result-prefixes="xsl office style text table draw xlink dc meta number svg chart dr3d math form script config fo help ooo"
>

<xsl:output method="xml" indent="yes" encoding="UTF-8"/>
<xsl:strip-space elements="*"/>
<xsl:param name="iso" select="'unknown_UNKNOWN'"/>
<!--
 for migrating pt_BR only
//-->

<xsl:template match="/">
	<xsl:call-template name="licheader" />
	<helpdocument version="1.0">
			<title xml-lang="{$iso}" id="tit"><xsl:value-of select="/office:document/office:meta/dc:subject"/></title>
		<xsl:apply-templates select="/office:document/office:body/*"/>
	</helpdocument>
</xsl:template>

<!--
 only migrate the following elements
//-->


<xsl:template match="text:p | text:h">
	<xsl:if test="not(.='')">
		<xsl:variable name="style">
			<xsl:call-template name="getparentstyle">
				<xsl:with-param name="stylename">
					<xsl:value-of select="@text:style-name"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="refno">
			<xsl:value-of select="help:paragraphinfo/@number"/>
		</xsl:variable>
		
		<paragraph xml-lang="{$iso}" role="{$style}" oldref="{$refno}">
			<xsl:apply-templates />
		</paragraph>
	</xsl:if>
</xsl:template>

<xsl:template match="draw:image/@svg:desc">
	<xsl:variable name="imgfn">
			<xsl:value-of select="ooo:resimgid(parent::draw:image/@xlink:href)"/>
	</xsl:variable>
	<image src="{$imgfn}" id="">
		<alt xml-lang="{$iso}" id=""><xsl:apply-templates/></alt>
	</image>
</xsl:template>

<xsl:template match="help:key-word">
	<!--
	<bookmark branch="index">
		<bookmark_value><xsl:value-of select="@value"/></bookmark_value>
	</bookmark>
	//-->
</xsl:template>

<xsl:template match="help:switch">
	<xsl:variable name="sel">	
		<xsl:choose>
			<xsl:when test="@select='Program'">
				<xsl:value-of select="'appl'"/>
			</xsl:when>
			<xsl:when test="@select='PROGRAM'">
				<xsl:value-of select="'appl'"/>
			</xsl:when>
			<xsl:when test="@select='System'">
				<xsl:value-of select="'sys'"/>
			</xsl:when>
			<xsl:when test="@select='SYSTEM'">
				<xsl:value-of select="'sys'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'error_unknown_switch'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:choose>
		<xsl:when test="ancestor::text:p or ancestor::text:h">
			<switchinline select="{$sel}">
				<xsl:apply-templates/>
			</switchinline>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="help:case">
<xsl:choose>
		<xsl:when test="ancestor::text:p or ancestor::text:h">
		<caseinline select="{@select}">
			<xsl:apply-templates/>
		</caseinline>
	</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates/>
		</xsl:otherwise>
	</xsl:choose>
	
</xsl:template>

<xsl:template match="help:default">
<xsl:choose>
		<xsl:when test="ancestor::text:p or ancestor::text:h">
		<defaultinline>
			<xsl:apply-templates/>
		</defaultinline>
	</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="help:help-text">
	<ahelp hid="" visibility="{@value}">
		<xsl:apply-templates />
	</ahelp>
</xsl:template>

<xsl:template match="help:link">
	<xsl:variable name="topic">
			<xsl:value-of select="ooo:resid(@Id)"/>
	</xsl:variable>
	<link href="{$topic}">
		<xsl:apply-templates />
	</link>
</xsl:template>

<xsl:template match="help:to-be-embedded">
	<xsl:choose>
		<xsl:when test="ancestor::text:p or ancestor::text:h">
			<variable id="{@Eid}">
				<xsl:apply-templates />
			</variable>
		</xsl:when>
		<xsl:otherwise>
				<xsl:apply-templates />
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="table:table">
		<xsl:for-each select="descendant::table:table-cell">
			<xsl:apply-templates />
		</xsl:for-each>
	</xsl:template>

<xsl:template match="text:unordered-list">
	<xsl:apply-templates/>
</xsl:template>
	
<xsl:template match="text:ordered-list">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="text:list-item">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="text:span">
	<emph><xsl:apply-templates /></emph>
</xsl:template>



<xsl:template match="*"/>


<xsl:template name="getparentstyle">
	<xsl:param name="stylename" />
	<xsl:variable name="parstyle">
		<xsl:value-of select="/office:document/office:automatic-styles/style:style[@style:name=$stylename]/@style:parent-style-name" />
	</xsl:variable>

	<xsl:choose>
		<xsl:when test="$parstyle != ''">
			<xsl:value-of select="$parstyle" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$stylename" />
		</xsl:otherwise>
	</xsl:choose>

	</xsl:template>


<xsl:template name="licheader">
	<xsl:comment>***********************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRUNTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRUNTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: Sun Microsystems, Inc..
 *
 *  Copyright: 2000 by Sun Microsystems, Inc.
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************</xsl:comment>
 
	</xsl:template>
	
</xsl:stylesheet>
